@@ -2,25 +2,24 @@
 PyXNAT
 ======
 
-pyxnat provides an API to access data on XNAT (see http://xnat.org)
-servers.
+:mod:`pyxnat` provides an API to access data on XNAT servers
+(see http://xnat.org).
 
-Visit http://packages.python.org/pyxnat for more information.
+Visit https://pyxnat.github.io/pyxnat for more information.
 """
 
 from .version import VERSION as __version__
 
 from .core import Interface
 from .core import SearchManager
-from .core import CacheManager
 from .core import Select
 from .core import Inspector
 from .core import Users
 from .core import attributes
-from .core import cache
 from .core import help
 from .core import interfaces
 from .core import resources
+from .core import manage
 from .core import schema
 from .core import select
 from .core import users
