@@ -1,6 +1,3 @@
-import os
-import sys
-
 from .interfaces import Interface
 from .search import SearchManager
 from .select import Select
