@@ -68,9 +68,9 @@ def find_plus_line(lines):
 # char -> str -> (str,str) | None
 def find_token(tok, line):
     splitString = list(map(lambda x: x.strip(), line.split(tok)))
-    print([line, tok, splitString])
+    #print([line, tok, splitString])
     if splitString is None or len(splitString) == 0 or len(splitString) == 1 \
             or splitString[0] == '':
         return None
     else:
-        return (splitString[0], splitString[1])
+        return (splitString[0], tok.join(splitString[1:]))
