@@ -2,12 +2,12 @@ import os
 from uuid import uuid1
 from pyxnat import Interface
 import os.path as op
-from . import skip_if_no_network
+from pyxnat.tests import skip_if_no_network
 
 
-fp = op.join(op.dirname(op.abspath(__file__)), 'central.cfg')
+fp = op.abspath('.devxnat.cfg')
 central = Interface(config=fp)
-project = central.select.project('nosetests5')
+project = central.select.project('pyxnat_tests')
 
 variables = {'Subjects': {'newgroup': {'foo': 'string', 'bar': 'int'}}}
 
