@@ -1,8 +1,6 @@
 from pyxnat import Interface
-import os.path as op
 
-fp = op.join(op.dirname(op.abspath(__file__)), 'central.cfg')
-central = Interface(config=fp)
+central = Interface('https://www.nitrc.org/ir', anonymous=True)
 
 
 def test_inspector_structure():
