@@ -1,12 +1,12 @@
 from uuid import uuid1
-from . import skip_if_no_network
+from pyxnat.tests import skip_if_no_network
 from pyxnat import Interface
 import os.path as op
 
 
-fp = op.join(op.dirname(op.abspath(__file__)), 'central.cfg')
+fp = op.abspath('.devxnat.cfg')
 central = Interface(config=fp)
-project = central.select.project('nosetests5')
+project = central.select.project('pyxnat_tests')
 
 prov = {
     'program': 'young',
